@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 2006-2020 The PHP Group                                |
+  | Copyright (c) The PHP Group                                          |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -68,6 +68,13 @@ using wformatter = basic_formatter<wchar_t>;
 using std_strings = std::vector<std::string>;
 using std_stringset = std::set<std::string>;
 
+void single_separator_split(
+        util::vector< util::string >& output,
+        const util::string& input,
+        const char separator
+);
+
+
 } // namespace util
 
 } // namespace mysqlx
